package #
Date::Manip::Offset::off000;
# Copyright (c) 2008-2019 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Thu Feb 28 13:07:59 EST 2019
#    Data version: tzdata2018i
#    Code version: tzcode2018i

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.76';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+00:00:00';

%Offset        = (
   0 => [
      'wet',
      'europe/london',
      'atlantic/faroe',
      'europe/lisbon',
      'africa/abidjan',
      'africa/sao_tome',
      'africa/accra',
      'atlantic/canary',
      'atlantic/madeira',
      'atlantic/reykjavik',
      'africa/monrovia',
      'africa/bissau',
      'america/danmarkshavn',
      'etc/gmt',
      'ut',
      'utc',
      'z',
      'antarctica/troll',
      'africa/casablanca',
      'africa/el_aaiun',
      'atlantic/azores',
      'africa/ceuta',
      'africa/algiers',
      'europe/dublin',
      'america/rankin_inlet',
      'europe/gibraltar',
      'america/inuvik',
      'indian/kerguelen',
      'america/resolute',
      'europe/andorra',
      'america/iqaluit',
      'europe/brussels',
      'europe/madrid',
      'europe/monaco',
      'europe/paris',
      'europe/luxembourg',
      'america/yellowknife',
      'america/pangnirtung',
      'america/cambridge_bay',
      'antarctica/casey',
      'antarctica/davis',
      'antarctica/dumontdurville',
      'antarctica/macquarie',
      'antarctica/mawson',
      'antarctica/palmer',
      'antarctica/rothera',
      'antarctica/syowa',
      'antarctica/vostok',
      ],
   1 => [
      'atlantic/azores',
      'europe/dublin',
      'america/scoresbysund',
      'africa/casablanca',
      'africa/el_aaiun',
      'atlantic/reykjavik',
      'atlantic/madeira',
      'europe/prague',
      ],
);

1;
